@@ -18,6 +18,7 @@
 
 #include "fuzztest/fuzztest.h"
 #include "gtest/gtest.h"
+#include "manifold/manifold.h"
 #include "manifold/optional_assert.h"
 #include "manifold/polygon.h"
 
@@ -26,7 +27,7 @@ using namespace fuzztest;
 void TriangulationNoCrash(
     std::vector<std::vector<std::pair<float, float>>> input, float precision) {
   if (precision < 0) precision = -1;
-  manifold::PolygonParams().intermediateChecks = true;
+  manifold::ManifoldParams().intermediateChecks = true;
   manifold::Polygons polys;
   size_t size = 0;
   for (const auto& simplePoly : input) {
@@ -36,11 +37,11 @@ void TriangulationNoCrash(
       size++;
     }
   }
-  std::atomic<pid_t> tid;
+  pthread_t tid;
   std::atomic<bool> faulted(true);
   auto asyncFuture =
       std::async(std::launch::async, [&polys, &faulted, &tid, precision]() {
-        tid.store(gettid());
+        tid = pthread_self();
         try {
           manifold::Triangulate(polys, precision);
           faulted.store(false);
@@ -54,7 +55,7 @@ void TriangulationNoCrash(
   if (asyncFuture.wait_for(std::chrono::milliseconds(
           std::max<size_t>(size, 10000))) == std::future_status::timeout) {
     printf("timeout after %ldms...\n", std::max<size_t>(size, 10000));
-    pthread_cancel(tid.load());
+    pthread_cancel(tid);
   }
 
   EXPECT_FALSE(faulted.load());
@@ -100,11 +101,6 @@ FUZZ_TEST(PolygonFuzz, TriangulationNoCrashRounded)
                  InRange<float>(-1.0, 0.1))
     .WithSeeds(SeedProvider);
 
-static std::vector<TestCase> TestCases;
-void TestPoly(Polygons polys, int _unused, float precision = -1.0) {
-  TestCases.push_back({polys, precision});
-}
-
 std::vector<TestCase> SeedProvider() {
   std::string file = __FILE__;
   std::string dir = file.substr(0, file.rfind('/'));
